@@ -26,11 +26,14 @@ class Property:
 			else: return self.__dict__[name]
 		else: raise TypeError("That is not a string!")
 
-	def __get__(self, name):
-		return get(name)
+	def __getattr__(self, name):
+		return self.get(name)
 
-	def __set__(self, name, val):
-		add(name, val)
+	def __setattr__(self, name, val):
+		self.add(name, val)
 
-	def __del__(self, name):
-		remove(name)
+	def __delattr__(self, name):
+		self.remove(name)
+	
+	def __exit__(self, exception_type, exception_value, exception_traceback):
+		del self.__dict__
